#include <Adafruit_NeoPixel.h>
#include <bluefruit.h>
#include <Adafruit_LittleFS.h>
#include <InternalFileSystem.h>

#include <Adafruit_CircuitPlayground.h>

#define GAS_SENSOR_PIN A1
#define LED_PIN A3
#define NUMPIXELS 30
#define BUTTON_A 4

Adafruit_NeoPixel strip(NUMPIXELS, LED_PIN, NEO_GRB + NEO_KHZ800);
BLEUart bleuart; // Bluetooth UART for data transmission
bool bluetoothEnabled = false;

void setup() {
  Serial.begin(9600);
  strip.begin();
  strip.show();
  CircuitPlayground.begin();
  
  // Initialize Bluetooth
  Bluefruit.begin();
  Bluefruit.setName("AirQualityMonitor");
  bleuart.begin();
  Bluefruit.Advertising.addService(bleuart);
  Bluefruit.Advertising.start();
}

void loop() {
  int sensorValue = analogRead(GAS_SENSOR_PIN);
  Serial.print("Gas Sensor Value: ");
  Serial.println(sensorValue);
  
  // Check if Button A is pressed to toggle Bluetooth mode
  if (CircuitPlayground.leftButton()) {
    bluetoothEnabled = !bluetoothEnabled;
    Serial.println(bluetoothEnabled ? "Bluetooth Mode ON" : "Bluetooth Mode OFF");
    delay(500); // Debounce delay
  }
  
  // Send data over Bluetooth if enabled
  if (bluetoothEnabled && Bluefruit.connected()) {
    bleuart.print("Gas Level: ");
    bleuart.println(sensorValue);
  }
  
  // Adjust LED strip chasing speed based on gas level
  int speedDelay = map(sensorValue, 0, 1023, 100, 10); // Faster chasing at higher values
  
  // Determine LED color based on gas sensor value
  uint32_t color;
  if (sensorValue < 300) {
    color = strip.Color(0, 255, 0); // Green
  } else if (sensorValue < 600) {
    color = strip.Color(0, 0, 255); // Blue
  } else {
    color = strip.Color(255, 0, 0); // Red
  }
  
  chase(color, speedDelay);
}

void chase(uint32_t color, int delayTime) {
  for (int i = 0; i < NUMPIXELS; i++) {
    strip.setPixelColor(i, color);
    strip.show();
    delay(delayTime);
    strip.setPixelColor(i, 0);
  }
}